@@ -1,22 +1,21 @@
-use std::path::PathBuf;
-use std::process;
+use std::env;
 use std::fs;
 use std::io::{self, Write};
+use std::path::PathBuf;
+use std::process;
 use std::rc::Rc;
-use std::env;
 
-use config::{ConfigError, Config, File};
-use directories::{UserDirs, ProjectDirs};
+use config::{Config, ConfigError, File};
+use directories::{ProjectDirs, UserDirs};
 
 use crate::Settings;
 
 impl Default for Settings {
     fn default() -> Self {
         if let Some(user_dirs) = UserDirs::new() {
-            let downloads_dir = user_dirs.download_dir().unwrap_or_else(|| {
-                eprintln!("Error getting downloads directory, falling back to home directory");
-                user_dirs.home_dir()
-            });
+            let downloads_dir = user_dirs
+                .download_dir()
+                .unwrap_or_else(|| user_dirs.home_dir());
 
             let downloads_dir: Rc<PathBuf> = Rc::new(PathBuf::from(downloads_dir));
             Settings {
@@ -24,8 +23,9 @@ impl Default for Settings {
                 tvshow_dir: Rc::clone(&downloads_dir),
                 movie_dir: Rc::clone(&downloads_dir),
                 default_directory: Rc::clone(&downloads_dir),
-                default_proxy: String::from(""), 
+                default_proxy: String::from(""),
                 autodownload: false,
+                torrent_client: String::from(""),
             }
         } else {
             eprintln!("Error getting home directory");
@@ -47,21 +47,21 @@ impl DownloadDirCache {
                     return DownloadDirCache { value: None };
                 }
                 Some(path)
-            },
+            }
             Err(_) => None,
         };
-        DownloadDirCache {
-            value
-        }
+        DownloadDirCache { value }
     }
 
     pub fn value(&mut self) -> Rc<PathBuf> {
         match &self.value {
-            Some(val) => Rc::clone(&val),
+            Some(val) => Rc::clone(val),
             None => {
                 if let Some(user_dirs) = UserDirs::new() {
                     let dir = user_dirs.download_dir().unwrap_or_else(|| {
-                        eprintln!("Error getting downloads directory, falling back to home directory");
+                        eprintln!(
+                            "Error getting downloads directory, falling back to home directory"
+                        );
                         user_dirs.home_dir()
                     });
 
@@ -79,7 +79,10 @@ impl DownloadDirCache {
 }
 
 impl Settings {
-    fn validate_path(path: Result<String, ConfigError>, default: &mut DownloadDirCache) -> Rc<PathBuf> {
+    fn validate_path(
+        path: Result<String, ConfigError>,
+        default: &mut DownloadDirCache,
+    ) -> Rc<PathBuf> {
         match path {
             Ok(v) => {
                 let mut path = Rc::new(PathBuf::from(v));
@@ -87,7 +90,7 @@ impl Settings {
                     path = default.value()
                 }
                 path
-            },
+            }
             Err(_) => default.value(),
         }
     }
@@ -98,7 +101,7 @@ impl Settings {
         if let Some(proj_dirs) = ProjectDirs::from("", "", "magnetfinder") {
             let config_path = proj_dirs.config_dir();
             let mut config_path = config_path.to_path_buf();
-            config_path.push("Settings.toml"); 
+            config_path.push("Settings.toml");
 
             s.merge(File::from(config_path))?;
         } else {
@@ -108,8 +111,10 @@ impl Settings {
                     exe_path.pop();
                     exe_path.push("Settings.toml");
                     s.merge(File::from(exe_path))?;
-                },
-                Err(_) => { s.merge(File::with_name("Settings"))?; }
+                }
+                Err(_) => {
+                    s.merge(File::with_name("Settings"))?;
+                }
             };
         }
 
@@ -120,8 +125,15 @@ impl Settings {
         let movie_dir = Settings::validate_path(s.get::<String>("movie_dir"), &mut fallback_dir);
 
         let autodownload = s.get_bool("autodownload").unwrap_or(false);
-        let default_proxy = s.get::<String>("default_proxy").unwrap_or(String::from(""));
-        
+
+        let torrent_client = s
+            .get::<String>("torrent_client")
+            .unwrap_or_else(|_| String::from(""));
+
+        let default_proxy = s
+            .get::<String>("default_proxy")
+            .unwrap_or_else(|_| String::from(""));
+
         Ok(Settings {
             anime_dir,
             tvshow_dir,
@@ -129,10 +141,11 @@ impl Settings {
             default_directory: fallback_dir.value(),
             default_proxy,
             autodownload,
+            torrent_client,
         })
     }
 
-    pub fn generate_settings_file() -> Result<(), io::Error>{
+    pub fn generate_settings_file() -> Result<(), io::Error> {
         let mut file;
 
         if let Some(proj_dirs) = ProjectDirs::from("", "", "magnetfinder") {
@@ -143,13 +156,13 @@ impl Settings {
                 fs::create_dir(&config_path)?;
             }
 
-            config_path.push("Settings.toml"); 
+            config_path.push("Settings.toml");
 
             file = fs::File::create(config_path)?;
         } else {
             eprintln!("Error finding project config directory, falling back to executable path");
             if let Ok(mut exe_path) = env::current_exe() {
-                exe_path.pop(); 
+                exe_path.pop();
                 exe_path.push("Settings.toml");
                 file = fs::File::create(exe_path)?;
             } else {
@@ -158,7 +171,7 @@ impl Settings {
         }
 
         file.write_all(
-b"# Change directories to where you want each type of media to download to,
+            b"# Change directories to where you want each type of media to download to,
 # or where default directory is in arg mode
 
 # use absolute paths (/home/user/Downloads/ , C:\\..\\user\\downloads\\ )
@@ -172,13 +185,17 @@ movie_dir = \"\"
 #[ Default Directory (Arg & Interactive Mode) ]
 default_directory = \"\"
 
+#[ Torrent Client ]
+# current supported clients are \"deluge\", and \"Transmission\" (ex: torrent_client = \"deluge\")
+torrent_client = \"\"
+
 # Autodownload takes the magnet link selected and
 # uses the torrent-client chosen to begin downloading the torrent
 autodownload = false
 
 # setting a default proxy allows you to tunnel all scraping from torrent websites through
 # this set proxy by default. If using a socks5 proxy, format ip like so: socks5://192.168.1.1:9000
-default_proxy = \"\""
+default_proxy = \"\"",
         )?;
 
         Ok(())
