@@ -39,7 +39,7 @@ impl Torrent {
 pub enum Website {
     Nyaa,
     Piratebay,
-    YTS
+    YTS,
 }
 
 pub enum Media {
@@ -53,6 +53,12 @@ pub enum Sort {
     Seeds,
 }
 
+pub enum TorrentClient {
+    Deluge,
+    Transmission,
+    Unknown,
+}
+
 pub struct Settings {
     pub anime_dir: Rc<PathBuf>,
     pub tvshow_dir: Rc<PathBuf>,
@@ -60,6 +66,7 @@ pub struct Settings {
     pub default_directory: Rc<PathBuf>,
     pub default_proxy: String,
     pub autodownload: bool,
+    pub torrent_client: String,
 }
 
 pub struct UserParameters {
@@ -68,6 +75,9 @@ pub struct UserParameters {
     pub search_query: Arc<String>,
     pub search_depth: u32,
     pub sort_preference: Sort,
+    pub num_torrents_shown: usize,
     pub proxy: Arc<String>,
     pub autodownload: bool,
+    pub torrent_client: TorrentClient,
+    pub no_interactive: bool,
 }
